using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;


namespace MapApp.Ui.Controls
{
    public class AppFormBase : Form
    {
        private static string HELP_FILE_PATH = Application.StartupPath + @"\MapApp.chm";

        private HelpProvider helpProvider;
        // remember if window was normal or maximized when it was iconised
        private FormWindowState _oldWindowState = FormWindowState.Normal;

        public AppFormBase()
        {
            InitializeComponent();
        }

        void InitializeComponent()
        {
            this.helpProvider = new System.Windows.Forms.HelpProvider();
            this.SuspendLayout();
            // 
            // helpProvider
            // 
            this.helpProvider.HelpNamespace = HELP_FILE_PATH;
            // 
            // AppFormBase
            // 
            this.ClientSize = new System.Drawing.Size(282, 257);
            this.Name = "AppFormBase";
            this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.AppForm_FormClosing);
            this.ResumeLayout(false);

        }

        void AppForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (e.CloseReason == CloseReason.UserClosing)
            {
                this.Hide();
                e.Cancel = true; // never close the form, just hide it.
            }
        }

        new public FormWindowState WindowState
        {
            get
            {
                if (base.WindowState != FormWindowState.Minimized)
                {
                    _oldWindowState = base.WindowState;
                }
                return base.WindowState;
            }
            set
            {
                base.WindowState = value;
                if (base.WindowState != FormWindowState.Minimized)
                {
                    _oldWindowState = base.WindowState;
                }
            }
        }

        /// <summary>
        /// Override Show() to uniconise window and bring it to front.
        /// </summary>
        new public void Show()
        {
            //this.WindowState = FormWindowState.Normal;
            this.WindowState = _oldWindowState;
            bool wasTopmost = this.TopMost;
            if (!wasTopmost)
            {
                this.TopMost = true;
            }
            base.Show();
            if (!wasTopmost)
            {
                this.TopMost = false;
            }
        }

    }
}
